#!/usr/bin/python3
"""
## © University of Southampton IT Innovation Centre, 2018
##
## Copyright in this software belongs to University of Southampton
## IT Innovation Centre of Gamma House, Enterprise Road, 
## Chilworth Science Park, Southampton, SO16 7NS, UK.
##
## This software may not be used, sold, licensed, transferred, copied
## or reproduced in whole or in part in any manner or form or in or
## on any media by any person other than in accordance with the terms
## of the Licence Agreement supplied with the software, or otherwise
## without the prior written consent of the copyright owners.
##
## This software is distributed WITHOUT ANY WARRANTY, without even the
## implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
## PURPOSE, except where stated in the Licence Agreement supplied with
## the software.
##
##      Created By :            Michael Boniface
##      Created Date :          02-03-2018
##      Created for Project :   FLAME
"""

import pytest
import time
import yaml
import json
import pkg_resources
from influxdb import InfluxDBClient


@pytest.fixture(scope="module")
def telegraf_agent_config(request):
    """
    Reads the service configuration deployed for the streaming simulation test.

    :param request: access the parameters of the fixture
    :return: the python object representing the read YAML file
    """
    rspec = pkg_resources.resource_filename('clmctest', 'rspec.json')
    print("\nrspec file: {0}".format(rspec))
    with open(rspec, 'r') as stream:
        data_loaded = json.load(stream)
    return data_loaded


@pytest.fixture(params=[{'database': 'CLMCMetrics'}], scope='module')
def influxdb(telegraf_agent_config, request):
    """
    Creates an Influx DB client for the CLMC metrics database with an empty database

    :param telegraf_agent_config: the fixture returning the yaml configuration
    :param request: access the parameters of the fixture
    :return: the created Influx DB client
    """
   
    db =  InfluxDBClient(host=telegraf_agent_config[0]['ip_address'], port=8086, database=request.param['database'], timeout=10)
    db.drop_database(request.param['database'])

    # wait 20 seconds for the 1st measurement to arrive from agents before returning
    time.sleep(30)

    return db
